@@ -110,9 +110,12 @@ class WikibaseQuery(object):
                         value=value.replace(wbPrefix,"")
                     valuesClause+=f"\n   ( wd:{value} )"
                 else:
-                    # escape single quotes
-                    value=value.replace("'","\\'")
-                    valuesClause+=f"\n  ( '{value}'{lang} )"
+                    if isinstance(value,str):
+                        # escape single quotes
+                        value=value.replace("'","\\'")
+                        valuesClause+=f"\n  ( '{value}'{lang} )"
+                    else:
+                        valuesClause+=f"\n  ( {str(value)} )"
         valuesClause+="\n  }."
         return valuesClause
         
@@ -185,7 +188,7 @@ SELECT ?item ?itemLabel ?itemDescription
         return sparql
             
     @classmethod
-    def sparqlOfGoogleSheet(cls,url:str,sheetName:str,entityName:str,pkColumn:str,mappingSheetName="Wikidata",lang:str="en",debug:bool=False):
+    def sparqlOfGoogleSheet(cls,url:str,sheetName:str,entityName:str,pkColumn:str,mappingSheetName="WikidataMapping",lang:str="en",debug:bool=False):
         '''
         get a sparql query for the given google sheet
         
@@ -217,7 +220,7 @@ SELECT ?item ?itemLabel ?itemDescription
         return query,sparql
                     
     @classmethod
-    def ofGoogleSheet(cls,url:str,sheetName:str="Wikidata",debug:bool=False)->dict:
+    def ofGoogleSheet(cls,url:str,sheetName:str="WikidataMapping",debug:bool=False)->dict:
         '''
         create a dict of wikibaseQueries from the given google sheets row descriptions
         
